@@ -4,7 +4,7 @@ import re
 class FileIO:
     @staticmethod
     def clean(varStr):
-        return re.sub('\W|^(?=\d)', '', varStr)
+        return re.sub('\W|^(?=\d)', '_', varStr)
 
     @classmethod
     def get_oss_rel_path(cls, path: str) -> str:
